@@ -76,8 +76,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/builder/.cache/aurutils/sync/python310/src/Python-3.10.18/coverage.info',
- 'COVERAGE_REPORT': '/home/builder/.cache/aurutils/sync/python310/src/Python-3.10.18/lcov-report',
+ 'COVERAGE_INFO': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/stable-diffusion-webui-git/deps/python310/src/Python-3.10.19/coverage.info',
+ 'COVERAGE_REPORT': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/stable-diffusion-webui-git/deps/python310/src/Python-3.10.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -132,7 +132,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -612,7 +612,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/usr/sbin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
@@ -789,7 +789,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python310/src/Python-3.10.18',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/stable-diffusion-webui-git/deps/python310/src/Python-3.10.19',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -831,10 +831,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python310/src/Python-3.10.18 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/stable-diffusion-webui-git/deps/python310/src/Python-3.10.19 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python310/src/Python-3.10.18 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/stable-diffusion-webui-git/deps/python310/src/Python-3.10.19 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -862,8 +862,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/builder/.cache/aurutils/sync/python310/src/Python-3.10.18',
- 'abs_srcdir': '/home/builder/.cache/aurutils/sync/python310/src/Python-3.10.18',
+ 'abs_builddir': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/stable-diffusion-webui-git/deps/python310/src/Python-3.10.19',
+ 'abs_srcdir': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/stable-diffusion-webui-git/deps/python310/src/Python-3.10.19',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
